@@ -1,7 +1,6 @@
 summary.folderh <- function(object, ...){
   summ.foldh <- lapply(object, summary, ...)
   attr(summ.foldh, "keys") <- attr(object, "keys")
-  class(summ.foldh) <- "summary.folderh"
+#  class(summ.foldh) <- "summary.folderh"
   return(summ.foldh)
 }
-  
\ No newline at end of file
